==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-zh_CN-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: zh_CN\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: ""

, "Calls"
: ""

, "Line"
: "线路"

, "Caller Id"
: "来电号码"

, "Start"
: "开始"

, "Connected"
: "已连接"

, "Disconnected"
: "已断开"

, "Duration"
: "持续时间"

, "Ringing"
: "振铃"

, "Direction"
: "方向"

, "Source"
: "源"

, "Destination"
: "目的"

, "Phone"
: ""

, "Phones"
: "电话"

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

, "Number"
: "号码"

, "Cancel"
: "取消"

, "Dial"
: "拨号"

, "Error"
: "错误"

, "Not possible to dial."
: "无法拨打电话。"

, "Edit phone settings"
: "编辑电话设置"

, "Dial number"
: "拨号"

, "Initiate a new outgoing call"
: "初始化一个新的向外呼叫"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Call contact"
: "致电联系人"

, "Work"
: "工作"

, "Home"
: "家庭"

, "Cell"
: "手机"

, "Cell private"
: "手机（私人）"

, "Incoming call"
: "打进的电话"

, "Outgoing call"
: "打出的电话"

, "unknown number"
: "未知号码"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Calls last week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Calls this month"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of last month"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.03.4.tar.bz2: Phone/js/Phone-lang-zh_CN-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nLanguage: zh_CN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "打进的电话"

, "Outgoing call"
: "打出的电话"

, "unknown number"
: "未知号码"

, "Phone"
: ""

, "Line"
: "线路"

, "Number"
: "号码"

, "Cancel"
: "取消"

, "Dial"
: "拨号"

, "Error"
: "错误"

, "Not possible to dial."
: "无法拨打电话。"

, "Call contact"
: "致电联系人"

, "Work"
: "工作"

, "Home"
: "家庭"

, "Cell"
: "手机"

, "Cell private"
: "手机（私人）"

, "Edit phone settings"
: "编辑电话设置"

, "Dial number"
: "拨号"

, "Initiate a new outgoing call"
: "初始化一个新的向外呼叫"

, "Phones"
: "电话"

, "No phone selected"
: ""

, "Please select the desired phone in the tree!"
: ""

, "Calls this week"
: ""

, "Calls last week"
: ""

, "Calls this month"
: ""

, "Calls last month"
: ""

, "Incoming and outgoing calls of this week"
: ""

, "Incoming and outgoing calls of last week"
: ""

, "Incoming and outgoing calls of this month"
: ""

, "Incoming and outgoing calls of last month"
: ""

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: ""

, "Calls"
: ""

, "Caller Id"
: "来电号码"

, "Start"
: "开始"

, "Connected"
: "已连接"

, "Disconnected"
: "已断开"

, "Duration"
: "持续时间"

, "Ringing"
: "振铃"

, "Direction"
: "方向"

, "Source"
: "源"

, "Destination"
: "目的"

, "resolved destination"
: ""

, "Settings"
: ""

, "Lines"
: ""

, "Description"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
